/// <reference types="express" />
import { Request } from '@loopback/rest';
import { IAuthUserWithPermissions, ILogger, SuccessResponse } from '@sourceloop/core';
import { AuthClient } from '../../models';
import { CodeReaderFn, CodeWriterFn, JwtPayloadFn } from '../../providers';
import { AuthClientRepository, OtpCacheRepository, RefreshTokenRepository, RevokedTokenRepository, RoleRepository, UserLevelPermissionRepository, UserLevelResourceRepository, UserRepository, UserTenantRepository } from '../../repositories';
import { TenantConfigRepository } from '../../repositories/tenant-config.repository';
import { LoginHelperService } from '../../services';
import { AuthRefreshTokenRequest, AuthTokenRequest, CodeResponse, LoginRequest, OtpLoginRequest, OtpResponse } from './';
import { AuthUser } from './models/auth-user.model';
import { ResetPassword } from './models/reset-password.dto';
import { TokenResponse } from './models/token-response.dto';
import { OtpSendRequest } from './models/otp-send-request.dto';
export declare class LoginController {
    private readonly client;
    private readonly user;
    authClientRepository: AuthClientRepository;
    userRepo: UserRepository;
    otpCacheRepo: OtpCacheRepository;
    roleRepo: RoleRepository;
    utPermsRepo: UserLevelPermissionRepository;
    userResourcesRepository: UserLevelResourceRepository;
    userTenantRepo: UserTenantRepository;
    refreshTokenRepo: RefreshTokenRepository;
    revokedTokensRepo: RevokedTokenRepository;
    tenantConfigRepo: TenantConfigRepository;
    private readonly req;
    logger: ILogger;
    private readonly getJwtPayload;
    private readonly loginHelperService;
    constructor(client: AuthClient | undefined, user: AuthUser | undefined, authClientRepository: AuthClientRepository, userRepo: UserRepository, otpCacheRepo: OtpCacheRepository, roleRepo: RoleRepository, utPermsRepo: UserLevelPermissionRepository, userResourcesRepository: UserLevelResourceRepository, userTenantRepo: UserTenantRepository, refreshTokenRepo: RefreshTokenRepository, revokedTokensRepo: RevokedTokenRepository, tenantConfigRepo: TenantConfigRepository, req: Request, logger: ILogger, getJwtPayload: JwtPayloadFn, loginHelperService: LoginHelperService);
    login(req: LoginRequest, client: AuthClient | undefined, user: AuthUser | undefined): Promise<CodeResponse>;
    loginWithClientUser(req: LoginRequest, deviceId?: string): Promise<TokenResponse>;
    getToken(req: AuthTokenRequest, codeReader: CodeReaderFn, deviceId?: string): Promise<TokenResponse>;
    exchangeToken(req: AuthRefreshTokenRequest, deviceId?: string, token?: string): Promise<TokenResponse>;
    resetPassword(req: ResetPassword, auth: string, currentUser: IAuthUserWithPermissions): Promise<SuccessResponse>;
    me(): Promise<AuthUser | undefined>;
    sendOtp(req: OtpSendRequest, client: AuthClient, user: AuthUser): Promise<OtpResponse | void>;
    verifyOtp(req: OtpLoginRequest, user: AuthUser | undefined, codeWriter: CodeWriterFn): Promise<CodeResponse>;
    private createJWT;
}
